class Library {
  constructor() {
    this.books = JSON.parse(localStorage.getItem('books')) || [];
    this.initializeUI();
    this.bindEvents();
    this.renderBooks();
  }

  initializeUI() {
    this.bookForm = document.getElementById('book-form');
    this.booksContainer = document.getElementById('books-container');
    this.searchInput = document.getElementById('search');
    this.filterGenre = document.getElementById('filter-genre');
    this.mobileMenu = document.querySelector('.mobile-menu');
    this.navLinks = document.querySelector('.nav-links');
  }

  bindEvents() {
    this.bookForm.addEventListener('submit', (e) => this.addBook(e));
    this.searchInput.addEventListener('input', () => this.filterBooks());
    this.filterGenre.addEventListener('change', () => this.filterBooks());
    this.mobileMenu.addEventListener('click', () => this.toggleMenu());
  }

  toggleMenu() {
    this.navLinks.classList.toggle('active');
  }

  addBook(e) {
    e.preventDefault();
    const book = {
      id: Date.now(),
      title: document.getElementById('title').value,
      author: document.getElementById('author').value,
      genre: document.getElementById('genre').value,
      date: new Date().toISOString()
    };

    this.books.push(book);
    this.saveBooks();
    this.renderBooks();
    this.bookForm.reset();

    // Show success message
    this.showNotification('Book added successfully!');
  }

  showNotification(message) {
    const notification = document.createElement('div');
    notification.className = 'notification';
    notification.textContent = message;
    document.body.appendChild(notification);

    setTimeout(() => {
      notification.remove();
    }, 3000);
  }

  removeBook(id) {
    this.books = this.books.filter(book => book.id !== id);
    this.saveBooks();
    this.renderBooks();
  }

  filterBooks() {
    const searchTerm = this.searchInput.value.toLowerCase();
    const selectedGenre = this.filterGenre.value;

    const filtered = this.books.filter(book => {
      const matchesSearch = book.title.toLowerCase().includes(searchTerm) ||
                          book.author.toLowerCase().includes(searchTerm);
      const matchesGenre = selectedGenre === 'all' || book.genre === selectedGenre;
      return matchesSearch && matchesGenre;
    });

    this.renderBooks(filtered);
  }

  renderBooks(booksToRender = this.books) {
    this.booksContainer.innerHTML = '';
    
    booksToRender.forEach(book => {
      const bookCard = document.createElement('div');
      bookCard.className = 'book-card';
      bookCard.innerHTML = `
        <h3>${book.title}</h3>
        <p>By ${book.author}</p>
        <p>Genre: ${book.genre}</p>
        <button onclick="library.removeBook(${book.id})">Remove</button>
      `;
      this.booksContainer.appendChild(bookCard);
    });
  }

  saveBooks() {
    localStorage.setItem('books', JSON.stringify(this.books));
  }
}

// Initialize the library when the DOM is loaded
document.addEventListener('DOMContentLoaded', () => {
  window.library = new Library();
});
